==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/InsertBlock/ts/InsertBlock_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Insert</name>
    <message>
        <source>Position</source>
        <translation type="obsolete">Posizione</translation>
    </message>
    <message>
        <source>&amp;Insert Block</source>
        <translation type="obsolete">&amp;Inserisci Blocco</translation>
    </message>
</context>
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Inserisci Blocco</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotazione:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Ruotare blocco&lt;br&gt;da questo angolo</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale X:</source>
        <translation>Scala X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Scala il blocco in X&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Scala il blocco in Y&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Mantiene proporzioni</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Rifletti blocco orizzontalmente</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Rifletti blocco&lt;br&gt;verticalmente</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation>Blocco singolo</translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation>Matrice di blocci</translation>
    </message>
    <message>
        <source>Attribute 1:</source>
        <translation type="obsolete">Attribute 1:</translation>
    </message>
    <message>
        <source>Attribute 2:</source>
        <translation type="obsolete">Attribute 2:</translation>
    </message>
    <message>
        <source>Attribute 3:</source>
        <translation type="obsolete">Attribute 3:</translation>
    </message>
    <message>
        <source>Move / Copy Options</source>
        <translation type="obsolete">Opzioni Spostamento</translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>Colonne:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>Righe:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>Interasse colonne:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>Interasse Righe:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">Rotazione:</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">Ruotare blocco&lt;br&gt;da questo angolo</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">Scala X:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">Scala il blocco in X&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">Mantiene proporzioni</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">Scala Y:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Scala il blocco in Y&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">Rifletti blocco orizzontalmente</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">Rifletti blocco&lt;br&gt;verticalmente</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/InsertBlock/ts/InsertBlock_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Insert</name>
    <message>
        <source>Position</source>
        <translation type="obsolete">Posizione</translation>
    </message>
    <message>
        <source>&amp;Insert Block</source>
        <translation type="obsolete">&amp;Inserisci Blocco</translation>
    </message>
</context>
<context>
    <name>InsertBlock</name>
    <message>
        <location filename="../InsertBlock.js" line="+108"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../InsertBlockInit.js" line="+2"/>
        <source>&amp;Insert Block</source>
        <translation>&amp;Inserisci blocco</translation>
    </message>
    <message>
        <location filename="../InsertBlock.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotazione:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation>Ruotare blocco&lt;br&gt;da questo angolo</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale X:</source>
        <translation>Scala X:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation>Scala il blocco in X&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation>Scala il blocco in Y&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Keep Proportions</source>
        <translation>Mantiene proporzioni</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation>Rifletti blocco orizzontalmente</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation>Rifletti blocco&lt;br&gt;verticalmente</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Single Block</source>
        <translation>Blocco singolo</translation>
    </message>
    <message>
        <location line="+17"/>
        <location filename="../InsertBlockDialog.ui" line="+14"/>
        <source>Array of Blocks</source>
        <translation>Matrice di blocci</translation>
    </message>
    <message>
        <source>Attribute 1:</source>
        <translation type="obsolete">Attribute 1:</translation>
    </message>
    <message>
        <source>Attribute 2:</source>
        <translation type="obsolete">Attribute 2:</translation>
    </message>
    <message>
        <source>Attribute 3:</source>
        <translation type="obsolete">Attribute 3:</translation>
    </message>
    <message>
        <source>Move / Copy Options</source>
        <translation type="obsolete">Opzioni Spostamento</translation>
    </message>
    <message>
        <location filename="../InsertBlockDialog.ui" line="+12"/>
        <source>Columns:</source>
        <translation>Colonne:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Rows:</source>
        <translation>Righe:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Column Spacing:</source>
        <translation>Interasse colonne:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Row Spacing:</source>
        <translation>Interasse Righe:</translation>
    </message>
</context>
<context>
    <name>Paste</name>
    <message>
        <source>Rotation:</source>
        <translation type="obsolete">Rotazione:</translation>
    </message>
    <message>
        <source>Rotate block&lt;br&gt;by this angle</source>
        <translation type="obsolete">Ruotare blocco&lt;br&gt;da questo angolo</translation>
    </message>
    <message>
        <source>Scale X:</source>
        <translation type="obsolete">Scala X:</translation>
    </message>
    <message>
        <source>Scale block in X&lt;br&gt;by this factor</source>
        <translation type="obsolete">Scala il blocco in X&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <source>Keep Proportions</source>
        <translation type="obsolete">Mantiene proporzioni</translation>
    </message>
    <message>
        <source>Scale Y:</source>
        <translation type="obsolete">Scala Y:</translation>
    </message>
    <message>
        <source>Scale block in Y&lt;br&gt;by this factor</source>
        <translation type="obsolete">Scala il blocco in Y&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;horizontally</source>
        <translation type="obsolete">Rifletti blocco orizzontalmente</translation>
    </message>
    <message>
        <source>Flip block&lt;br&gt;vertically</source>
        <translation type="obsolete">Rifletti blocco&lt;br&gt;verticalmente</translation>
    </message>
</context>
</TS>
